# woptics

Wave optics in Python.
Simulates light propogation through free-space, optical fibres, etc. using the scalar-wave approximation.

## Install

```sh
pip install woptics
```

## Usage

```python
import woptics
```

## Contributing

Contributions are welcome!
Please read [CONTRIBUTING.md](./CONTRIBUTING.md) before submitting a PR.

## Versioning

We use [SemVer](http://semver.org/) for versioning.
Currently the project does not have a stable release, but once it does, have a look on the [tags page](https://github.com/rjkilpatrick/woptics/tags).

## License

This project is licensed under the MIT License - see the [LICENSE.md](./LICENSE.md) file for details
